#include "main.h"

#ifdef USE_SOUND
#include <mikmod.h>
    SAMPLE *MissileExplosionSound=NULL,*BombExplosionSound=NULL,*GameoverSound=NULL,*CitySound=NULL,*ClickSound=NULL;
    MODULE *Music[MUSICNUM];
    char ModName[MUSICNUM][20]=	{"ramagard.s3m","icefront.s3m","pennight.mod"};

    int sound=1;
    int mikmod_init=0;
#else
    int sound=0;
    int mikmod_init=0;
    void *MissileExplosionSound,*BombExplosionSound,*GameoverSound,*CitySound,*ClickSound;
    void *Music[MUSICNUM];
#endif
    int CurrentMusic=0;

void PlayMusic()
{
#ifdef USE_SOUND
	if (!sound) return;
    
    CurrentMusic = abrand(0, MUSICNUM-1);
    printf("Now playing song #%d\n", CurrentMusic);
    if ( ! Player_Active() )
	Player_Start(Music[CurrentMusic]);

#endif
}

void SetVol()
{
#ifdef USE_SOUND
    if (!sound) return;
    

#endif
}

void InitSound()
{
#ifdef USE_SOUND

    fprintf(stdout,"*** INIT SOUND ***\n");

    int i,ChannelNum;
    char text[200];
	
    if (!sound) return;

  if (drv_oss.Name)  // Valid OSS driver
  {
    if (drv_oss.CommandLine)  // Valid Commandline
    {
      drv_oss.CommandLine("buffer=14,count=2");
    }
    MikMod_RegisterDriver(&drv_oss);
  }
  if (drv_alsa.Name)  // Valid ALSA driver
  {
    if (drv_alsa.CommandLine)  // Valid Commandline
    {
      drv_alsa.CommandLine("buffer=14");
    }
    MikMod_RegisterDriver(&drv_alsa);
  }
  MikMod_RegisterDriver(&drv_nos);

  // register standard tracker
  MikMod_RegisterAllLoaders();

  // Note, the md_mode flags are already set by default
  md_mode |= DMODE_SOFT_SNDFX | DMODE_SOFT_MUSIC;

   if (MikMod_Init(""))  // Command paramenters are ignored as all drivers are registered
  {
    printf("mikmod init failure\n");
    exit(1);
  }

  printf("loaded mikmod drivers: %s\n",MikMod_InfoDriver());

		printf("** Loading Music **\n");
		for (i=0;i<MUSICNUM;i++) {
			sprintf(text,"%s/sound/%s",DATAPATH,ModName[i]);
			Music[i] = Player_Load(text, 64, 0);
    
		    if ( Music[i] == NULL ) {
			fprintf(stderr, "Could not load module, reason: %s\n",
            		MikMod_strerror(MikMod_errno));
			exit(1);
		    }

		}
    MikMod_SetNumVoices(-1, 4);
    MikMod_EnableOutput();
    md_sndfxvolume = 100;
    md_musicvolume = 70;

    md_volume=40;
      
    sprintf(text,"%s/sound/%s",DATAPATH,"click.wav");
    if ( (ClickSound = Sample_Load(text)) == NULL ) {
	fprintf(stdout,"Failed to load sound: %s\n",MikMod_strerror(MikMod_errno));
	exit(1);
    }
    
    sprintf(text,"%s/sound/%s",DATAPATH,"missex.wav");
    if ( (MissileExplosionSound = Sample_Load(text)) == NULL ) {
	fprintf(stdout,"Failed to load sound: %s\n",MikMod_strerror(MikMod_errno));
	exit(1);
    }
    sprintf(text,"%s/sound/%s",DATAPATH,"Wooeep.wav");
    if ( (CitySound = Sample_Load(text)) == NULL ) {
	fprintf(stdout,"Failed to load sound: %s\n",MikMod_strerror(MikMod_errno));
	exit(1);
    }

    sprintf(text,"%s/sound/%s",DATAPATH,"Machine.wav");
    if ( (GameoverSound = Sample_Load(text)) == NULL ) {
	fprintf(stdout,"Failed to load sound: %s\n",MikMod_strerror(MikMod_errno));
	exit(1);
    }

    sprintf(text,"%s/sound/%s",DATAPATH,"bombex.wav");
    if ( (BombExplosionSound = Sample_Load(text)) == NULL ) {
	fprintf(stdout,"Failed to load sound: %s\n",MikMod_strerror(MikMod_errno));
	exit(1);
    }
    
#endif
}

void PlaySound(SAMPLE *Sample)
{
#ifdef USE_SOUND
    if (sound && Sample != NULL) {
	int sid=Sample_Play(Sample,0,0);
	Voice_SetVolume(sid,md_sndfxvolume);
//	printf("Playing on channel %d\n",Mix_PlayChannel(-1,Sample,0));
//		Mix_PlayChannel(-1,Sample,0);
    }
#endif
}

void increaseMusicVolume(void)
{
	if (md_musicvolume >= 128) md_musicvolume = 128;
	else md_musicvolume += 1;
	printf("mdmusic volume: %d\n",md_musicvolume);
	SDL_Delay(30);
}

void increaseSoundVolume(void)
{
	if (md_sndfxvolume >= 128) md_sndfxvolume = 128;
	else md_sndfxvolume += 1;
	printf("md fxvolume: %d\n",md_sndfxvolume);
	SDL_Delay(30);
}

void decreaseMusicVolume(void)
{
	if (md_musicvolume <= 0) md_musicvolume = 0;
	else md_musicvolume -= 1;
	printf("mdmusic volume: %d\n",md_musicvolume);
	SDL_Delay(30);
}

void decreaseSoundVolume(void)
{
	if (md_sndfxvolume <= 0) md_sndfxvolume = 0;
	else md_sndfxvolume -= 1;
	printf("md fxvolume: %d\n",md_sndfxvolume);
	SDL_Delay(30);
}

void increaseVolume(void)
{
	if (md_volume >= 128) md_volume = 128;
	else md_volume += 1;
	printf("md volume: %d\n",md_volume);
	SDL_Delay(30);
}

void decreaseVolume(void)
{
	if (md_volume <= 0) md_volume = 0;
	else md_volume -= 1;
	printf("md volume: %d\n",md_volume);
	SDL_Delay(30);
}

void closeAudio(void) 
{
  MikMod_DisableOutput();
  Player_Stop();
  MikMod_Update();

//  Player_Free(music);

//  Sample_Free(chunk[i]);

  MikMod_Update();
  MikMod_Exit();
}
